@@ -4,14 +4,15 @@
 # Copyright (c) 1999-2007 Red Hat, Inc.
 # Author: Simo Sorce <ssorce@redhat.com>
 #
-# This is free software; you can redistribute it and/or modify it
-# under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 only
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 3 of the License, or
+# (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# General Public License for more details.
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
@@ -340,7 +341,7 @@ class IPAChangeConf(object):
         #First we create a new opts tree from oldopts removing/commenting
         #  the options as indicated by the contents of newopts
         #Second we fill in the new opts tree with options as indicated
-        #  in the newopts tree (this is becaus eentire (sub)sections may
+        #  in the newopts tree (this is because entire (sub)sections may
         #  exist in the newopts that do not exist in oldopts)
 
         opts = self.mergeOld(oldopts, newopts)
@@ -456,7 +457,7 @@ class IPAChangeConf(object):
 
             f = openLocked(file, 0o644)
 
-            # Trunkate
+            # Truncate
             f.seek(0)
             f.truncate(0)
 
@@ -471,14 +472,14 @@ class IPAChangeConf(object):
                 pass
         return True
 
-# A SSSD-specific subclass of IPAChangeConf
+# An SSSD-specific subclass of IPAChangeConf
 class SSSDChangeConf(IPAChangeConf):
     OPTCRE = re.compile(
             r'(?P<option>[^:=\s][^:=]*)'          # very permissive!
             r'\s*=\s*'                            # any number of space/tab,
                                                   # followed by separator
                                                   # followed by any # space/tab
-            r'(?P<value>.*)$'                     # everything up to eol
+            r'(?P<value>.*)$'                     # everything up to EOL
             )
 
     def __init__(self):
@@ -489,7 +490,7 @@ class SSSDChangeConf(IPAChangeConf):
 
     def parseLine(self, line):
         """
-        Overrides IPAChangeConf parseLine so that lines are splitted
+        Overrides IPAChangeConf parseLine so that lines are split
         using any separator in self.assign, not just the default one
         """
 
